<?php
namespace Frel\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Frel\Frel_Helper;


// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) { exit; }


/**
 * Frel Site Title
 */
class Frel_Project_Category_Filter extends Widget_Base {

	public function get_name() {
		return 'frel-project-category-filter';
	}

	public function get_title() {
		return __( 'Portfolio with category filter', 'frenify-core' );
	}

	public function get_icon() {
		return 'eicon-post';
	}

	public function get_categories() {
		return [ 'frel-elements' ];
	}

	protected function _register_controls() {
		
		$this->start_controls_section(
			'section1',
			[
				'label' => __( 'Portfolio', 'frenify-core' ),
			]
		);
		
		$this->add_control(
			'dark_mode',
			[
				'label' 	=> __( 'Dark Mode', 'frenify-core' ),
				'type' 		=> \Elementor\Controls_Manager::SELECT,
				'default' 	=> 'fn_light_mode',
				'options' 	=> [
					'fn_dark_mode'  => __( 'Enabled', 'frenify-core' ),
					'fn_light_mode'  => __( 'Disabled', 'frenify-core' ),
				],
			]
		);
		
		$this->add_control(
			'post_number',
			[
				'label' => __( 'Post Number', 'frenify-core' ),
				'type' => Controls_Manager::SLIDER,
				'default' => [
					'size' => 5,
				],
				'range' => [
					'px' => [
						'min' => -1,
						'max' => 999,
						'step' => 1,
					]
				],
				'condition' => [
					'items_type' => 'portfolio',
				]
			]
		);
		
		$this->add_control(
			'post_include_categories',
			[
				 'label'	 	=> __( 'Include Categories', 'frenify-core' ),
				 'description'	=> __( 'Select a category to include or leave blank for all.', 'frenify-core' ),
				 'type' 		=> Controls_Manager::SELECT2,
				 'multiple'	 	=> true,
				 'label_block'	=> true,
				 'options' 		=> Frel_Helper::getAllCategories('project_category')
			]
		);
		$this->add_control(
			'post_exclude_categories',
			[
				 'label'	 	=> __( 'Exclude Categories', 'frenify-core' ),
				 'description'	=> __( 'Select a category to exclude', 'frenify-core' ),
				 'type' 		=> Controls_Manager::SELECT2,
				 'multiple'	 	=> true,
				 'label_block'	=> true,
				 'options' 		=> Frel_Helper::getAllCategories('project_category')
			]
		);
		
		$this->add_control(
			'post_included_items',
			[
				 'label'	 	=> __( 'Include Posts', 'frenify-core' ),
				 'type' 		=> Controls_Manager::SELECT2,
				 'multiple'	 	=> true,
				 'label_block'	=> true,
				 'options' 		=> Frel_Helper::getAllPortfolioItems()
			]
		);
		
		
		$this->add_control(
			'post_excluded_items',
			[
				 'label'	 	=> __( 'Exclude Posts', 'frenify-core' ),
				 'type' 		=> Controls_Manager::SELECT2,
				 'multiple'	 	=> true,
				 'label_block'	=> true,
				 'options' 		=> Frel_Helper::getAllPortfolioItems()
			]
		);
		
		$this->add_control(
            'post_offset',
            [
                'label' => esc_html__( 'Post Offset', 'frenify-core' ),
                'type' => Controls_Manager::NUMBER,
                'default' => '0'
            ]
        );
		
		$this->add_control(
            'post_order',
            [
                'label' => esc_html__( 'Post Order', 'frenify-core' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'asc' 	=> esc_html__( 'Ascending', 'frenify-core' ),
                    'desc' 	=> esc_html__( 'Descending', 'frenify-core' )
                ],
                'default' => 'desc',

            ]
        );
		
		$this->add_control(
            'post_orderby',
            [
                'label' => esc_html__( 'Post Orderby', 'frenify-core' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'select' 			=> esc_html__( 'Select Option', 'frenify-core' ),
                    'ID' 				=> esc_html__( 'By ID', 'frenify-core' ),
                    'author' 			=> esc_html__( 'By Author', 'frenify-core' ),
                    'title' 			=> esc_html__( 'By Title', 'frenify-core' ),
                    'name' 				=> esc_html__( 'By Name', 'frenify-core' ),
                    'rand' 				=> esc_html__( 'Random', 'frenify-core' ),
                    'comment_count' 	=> esc_html__( 'By Number of Comments', 'frenify-core' ),
                    'menu_order' 		=> esc_html__( 'By Page Order', 'frenify-core' ),
                ],
                'default' => 'select',

            ]
        );
		
		$this->add_control(
            'category_filter',
            [
                'label' => esc_html__( 'Category Filter', 'frenify-core' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'disable' 	=> esc_html__( 'Disable', 'frenify-core' ),
                    'enable' 	=> esc_html__( 'Enable', 'frenify-core' )
                ],
                'default' => 'enable',

            ]
        );
		
		$this->add_control(
			'all_text',
			  [
				 'label'       => __( 'All Text', 'frenify-core' ),
				 'type'        => Controls_Manager::TEXTAREA,
				 'placeholder' => __( 'Type all text here', 'frenify-core' ),
				 'default' 	   => __( 'All', 'frenify-core' ),
			  ]
		);
		$this->end_controls_section();

		

		$this->start_controls_section(
			'section3',
			[
				'label' => __( 'Coloring', 'frenify-core' ),
			]
		);
		$this->add_control(
			'heading_project',
			[
				'label' 	=> __( 'Projects', 'frenify-core' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
			'category_color',
			[
				'label' => __( 'Category Color', 'frenify-core' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .fn_cs_project_category ul.posts_filter li a' => 'color: {{VALUE}};',
				],
				'default' => '#000',
				'condition' => [
					'dark_mode' => 'fn_light_mode',
				]
			]
		);
		$this->add_control(
			'category_active_color',
			[
				'label' => __( 'Category Active & Hover Color', 'frenify-core' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .fn_cs_project_category ul.posts_filter li a:hover,{{WRAPPER}} .fn_cs_project_category ul.posts_filter li a.current' => 'color: {{VALUE}};',
				],
				'default' => '#ff4b36',
			]
		);
		$this->add_control(
			'moving_bg_color',
			[
				'label' => __( 'Moving Content Background Color', 'frenify-core' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .fn_cs_project_moving_title,{{WRAPPER}} .fn_cs_project_moving_title span' => 'background-color: {{VALUE}};',
				],
				'default' => '#fff',
			]
		);
		$this->add_control(
			'moving_text_color',
			[
				'label' => __( 'Moving Content Text Color', 'frenify-core' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .fn_cs_project_moving_title h3,{{WRAPPER}} .fn_cs_project_moving_title span' => 'color: {{VALUE}};',
				],
				'default' => '#000',
			]
		);
		
		/**************************************/
		/************** DARK mode *************/
		/**************************************/
		
		$this->add_control(
			'dark_category_color',
			[
				'label' => __( 'Category Color', 'frenify-core' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .fn_cs_project_category ul.posts_filter li a' => 'color: {{VALUE}};',
				],
				'default' => '#fff',
				'condition' => [
					'dark_mode' => 'fn_dark_mode',
				]
			]
		);
		
		$this->end_controls_section();
		
	}




	protected function render() {
		$title = get_bloginfo( 'name' );

		if ( empty( $title ) )
			return;

		
		$settings 					= $this->get_settings();
		$dark_mode 					= $settings['dark_mode'];;
		$allText 					= $settings['all_text'];;
		$category_filter 			= $settings['category_filter'];;
		
		
		$postIncludedItems			= array();
		if(!empty($settings['post_included_items'])){
			$postIncludedItems		= $settings['post_included_items'];
		}
		$postExcludedItems			= array();
		if(!empty($settings['post_excluded_items'])){
			$postExcludedItems		= $settings['post_excluded_items'];
		}

		// portfolio posts options
		$include_categories 		= '';
		if(!empty($settings['post_include_categories'])){
			$include_categories 	= $settings['post_include_categories'];
		}
		$exclude_categories 		= '';
		if(!empty($settings['post_exclude_categories'])){
			$exclude_categories	 	= $settings['post_exclude_categories'];
		}
		$post_number 	= $settings['post_number']['size'];
		$post_order 	= $settings['post_order'];
		$post_orderby 	= $settings['post_orderby'];
		$post_offset 	= $settings['post_offset'];
		if($post_orderby === 'select'){
			$post_orderby 	= '';
		}

		$query_args = array(
			'post_type' 			=> 'arlo-project',
			'posts_per_page' 		=> $post_number,
			'post_status' 			=> 'publish',
			'order' 				=> $post_order,
			'orderby' 				=> $post_orderby,
			'offset' 				=> $post_offset,
			'post__in' 				=> $postIncludedItems,
			'post__not_in'	 		=> $postExcludedItems,
		);

		if ( ! empty ( $exclude_categories ) ) {

			// Exclude the correct cats from tax_query
			$query_args['tax_query'] = array(
				array(
					'taxonomy'	=> 'project_category', 
					'field'	 	=> 'slug',
					'terms'		=> $exclude_categories,
					'operator'	=> 'NOT IN'
				)
			);

			// Include the correct cats in tax_query
			if ( ! empty ( $include_categories ) ) {
				$query_args['tax_query']['relation'] = 'AND';
				$query_args['tax_query'][] = array(
					'taxonomy'	=> 'project_category',
					'field'		=> 'slug',
					'terms'		=> $include_categories,
					'operator'	=> 'IN'
				);
			}		

		} else {
			// Include the cats from $cat_slugs in tax_query
			if ( ! empty ( $include_categories ) ) {
				$query_args['tax_query'] = array(
					array(
						'taxonomy' 	=> 'project_category',
						'field' 	=> 'slug',
						'terms' 	=> $include_categories,
						'operator'	=> 'IN'
					)
				);
			}
		}

		$arlo_post_loop 			= new \WP_Query($query_args);
		
		
		$fnFilter 	= '<ul class="posts_filter">';
		$fnFilter 	.= '<li><a href="#" class="current" data-filter="*">'.$allText.'</a></li>';
		$filterItems	= '';
		$postList	= '<ul class="posts_list">';
		
		$html = Frel_Helper::frel_open_wrap();
		$html .= '<div class="fn_cs_project_category '.$dark_mode.'"><div class="container"><div class="inner">';
		$html .= '<div class="fn_cs_project_moving_title"></div>';
		foreach ( $arlo_post_loop->posts as $fn_post ) {
			setup_postdata( $fn_post );
			$post_id 			= $fn_post->ID;
			$post_permalink 	= get_permalink($post_id);
			$post_image 		= get_the_post_thumbnail_url( $post_id, 'full' );
			$post_title			= $fn_post->post_title;
			$post_taxonomy		= Frel_Helper::post_taxanomy('arlo-project');
			
			$post_cats			= Frel_Helper::post_term_list($post_id, $post_taxonomy[0], false, 9999, ', ');
			
			$categoriesWithSpecSymbol 	= Frel_Helper::post_term_list_second($post_id, $post_taxonomy[0], false, '////');
			
			$categoriesWithUnderscore 	= Frel_Helper::post_term_list_second($post_id, $post_taxonomy[0], false, ' ', true);
			$categoriesWithComma 		= Frel_Helper::post_term_list_second($post_id, $post_taxonomy[0], false, ' / ');
			
			$imgHolder			= '<div class="img_holder"><img src="'.FREL_PLUGIN_URL.'assets/img/thumb-square.jpg" alt="" /><div class="abs_img" data-bg-img="'.$post_image.'"><a href="'.$post_permalink.'"></a></div></div>';
			$hiddenTitleHolder	= '<div class="title_holder"><h3><a href="'.$post_permalink.'">'.$post_title.'</a></h3><p>'.$post_cats.'</p></div>';
			
			$postList .= '<li class="'.$categoriesWithUnderscore.'"><div class="item" data-title="'.$post_title.'" data-category="'.$categoriesWithComma.'">'.$imgHolder.$hiddenTitleHolder.'</div></li>';
			
			
			$filterItems .= $categoriesWithSpecSymbol.'////';
			wp_reset_postdata();
		}
		$removedLastCharacter 	= rtrim($filterItems,"////"); 				// remove last character from string
		$stringToArray 			= explode("////", $removedLastCharacter);	// string to array
		$removeUniqueElements 	= array_unique($stringToArray);				// remove unique elements from array
		
		foreach($removeUniqueElements as $item){
			$termName 	 = str_replace(' ', '_', $item);
			$fnFilter 	.= '<li><a href="#" data-filter=".'.$termName.'">'.$item.'</a></li>';
		}
		
		$postList 	.= '</ul>';
		$fnFilter 	.= '</ul>';
		$fnFilter 	.= '<div class="fn_clearfix"></div>';
		if($category_filter == 'enable'){
			$html .= $fnFilter;
		}
		
		$html .= $postList;
		$html .= '</div></div></div>';
		$html .= Frel_Helper::frel_close_wrap();
		echo $html;
	}

}
