<?php
namespace Frel\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Frel\Frel_Helper;


// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) { exit; }


/**
 * Frel Site Title
 */
class Frel_Universal_List_Filter_Masonry extends Widget_Base {

	public function get_name() {
		return 'frel-universal-list-filter-masonry';
	}

	public function get_title() {
		return __( 'Portfolio Filter Masonry', 'frenify-core' );
	}

	public function get_icon() {
		return 'eicon-post';
	}

	public function get_categories() {
		return [ 'frel-elements' ];
	}

	protected function _register_controls() {
		
		$this->start_controls_section(
			'section1',
			[
				'label' => __( 'List Content', 'frenify-core' ),
			]
		);
		
		
		$this->add_control(
			'post_number',
			[
				'label' 	=> __( 'Post Number', 'frenify-core' ),
				'type' 		=> Controls_Manager::SLIDER,
				'default' 	=> [
					'size' => 20,
				],
				'range' => [
					'px' => [
						'min' => -1,
						'max' => 9999,
						'step' => 1,
					]
				],
			]
		);
		
		$this->add_control(
            'post_offset',
            [
                'label' => esc_html__( 'Post Offset', 'frenify-core' ),
                'type' => Controls_Manager::NUMBER,
                'default' => '0',
            ]
        );
		
		$this->add_control(
            'post_order',
            [
                'label' => esc_html__( 'Post Order', 'frenify-core' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'asc' 	=> esc_html__( 'Ascending', 'frenify-core' ),
                    'desc' 	=> esc_html__( 'Descending', 'frenify-core' )
                ],
                'default' => 'desc',
            ]
        );
		
		$this->add_control(
            'post_orderby',
            [
                'label' => esc_html__( 'Post Orderby', 'frenify-core' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'select' 			=> esc_html__( 'Select Option', 'frenify-core' ),
                    'ID' 				=> esc_html__( 'By ID', 'frenify-core' ),
                    'author' 			=> esc_html__( 'By Author', 'frenify-core' ),
                    'title' 			=> esc_html__( 'By Title', 'frenify-core' ),
                    'name' 				=> esc_html__( 'By Name', 'frenify-core' ),
                    'rand' 				=> esc_html__( 'Random', 'frenify-core' ),
                    'comment_count' 	=> esc_html__( 'By Number of Comments', 'frenify-core' ),
                    'menu_order' 		=> esc_html__( 'By Page Order', 'frenify-core' ),
                ],
                'default' => 'select',
            ]
        );
		$this->end_controls_section();
		
		
		$this->start_controls_section(
			'section_show',
			[
				'label' => __( 'Category Section', 'frenify-core' ),
			]
		);
		
		
		$this->add_control(
            'category_filter',
            [
                'label' => esc_html__( 'Category Filter', 'frenify-core' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'disable' 	=> esc_html__( 'Disable', 'frenify-core' ),
                    'enable' 	=> esc_html__( 'Enable', 'frenify-core' )
                ],
                'default' => 'enable',

            ]
        );
		
		$this->add_control(
			'show_all_text',
			  [
				'label'       	=> __( 'Show All Text', 'frenify-core' ),
				'type'        	=> Controls_Manager::TEXT,
				'label_block'	=> true,
				'default' 	   	=> __( 'Show All', 'frenify-core' ),
			  ]
		);
		
		$this->add_control(
			'show_all_url',
			  [
				'label'       	=> __( 'Show All URL', 'frenify-core' ),
				'type'        	=> Controls_Manager::TEXT,
				'label_block'	=> true,
				'default' 	   	=> '#',
			  ]
		);
		
		$this->add_control(
			'all_text',
			  [
				'label'       	=> __( 'Category All Text', 'frenify-core' ),
				'type'        	=> Controls_Manager::TEXT,
				'label_block'	=> true,
				'default' 	   	=> __( 'All', 'frenify-core' ),
			  ]
		);
		
		$this->end_controls_section();

		

		$this->start_controls_section(
			'section3',
			[
				'label' => __( 'Coloring', 'frenify-core' ),
			]
		);
		
		$this->add_control(
			'project_color',
			[
				'label' => __( 'Project Color', 'frenify-core' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .fn_cs__ul__filter_masonry ul.posts_list .title_holder h3 a' => 'color: {{VALUE}};',
				],
				'default' => '#fff',
			]
		);
		
		$this->add_control(
			'project_hover_color',
			[
				'label' => __( 'Project Hover Color', 'frenify-core' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .fn_cs__ul__filter_masonry ul.posts_list .title_holder h3 a:hover' => 'color: {{VALUE}};',
				],
				'default' => '#ff4b36',
			]
		);
		
		$this->add_control(
			'category_color',
			[
				'label' => __( 'Category Color', 'frenify-core' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .fn_cs__ul__filter_masonry ul.posts_list .title_holder p a' => 'color: {{VALUE}};',
				],
				'default' => '#ccc',
			]
		);
		
		$this->add_control(
			'filter_color',
			[
				'label' => __( 'Filter Color', 'frenify-core' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .fn_cs__ul__filter_masonry .posts_filter a' => 'color: {{VALUE}};',
				],
				'default' => '#000',
			]
		);
		
		$this->add_control(
			'filter_active_color',
			[
				'label' => __( 'Filter Active Color', 'frenify-core' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .fn_cs__ul__filter_masonry .posts_filter a.current' => 'color: {{VALUE}};',
				],
				'default' => '#ff4b36',
			]
		);
		
		$this->end_controls_section();
		
	}




	protected function render() {
		$title = get_bloginfo( 'name' );

		if ( empty( $title ) )
			return;

		
		$settings 					= $this->get_settings();
		$show_text					= $settings['show_all_text'];
		$show_url					= $settings['show_all_url'];
		$all_text					= $settings['all_text'];
		$show_all					= '<div class="show_all"><a href="'.$show_url.'">'.$show_text.'</a></div>';
		if($show_text == '' || $show_url == ''){$show_all = '';}
		
		
		
		$post_number 				= $settings['post_number']['size'];
		$post_order 				= $settings['post_order'];
		$post_orderby 				= $settings['post_orderby'];
		$post_offset 				= $settings['post_offset'];
		$category_filter 			= $settings['category_filter'];
		if($post_orderby === 'select'){
			$post_orderby 	= '';
		}
		
		
		$query_args = array(
			'post_type' 			=> 'arlo-project',
			'posts_per_page' 		=> $post_number,
			'post_status' 			=> 'publish',
			'order' 				=> $post_order,
			'orderby' 				=> $post_orderby,
			'offset' 				=> $post_offset,
		);
		
		
		
		
		$arlo_post_loop = new \WP_Query($query_args);
		
		
		$fn_filter 		 = '<div class="posts_filter">';
		$fn_filter 		.= '<div><a href="#" class="current" data-filter="*">'.$all_text.'</a></div>';
		$post_cats3		 = '';
		$fn_list		 = '<div class="list_wrapper"><ul class="posts_list">';
		
		$html 			 = Frel_Helper::frel_open_wrap();
		$html 			.= '<div class="fn_cs__ul__filter_masonry"><div class="inner">';
		
		foreach ( $arlo_post_loop->posts as $fn_post ) {
			setup_postdata( $fn_post );
			$post_id 			= $fn_post->ID;
			$post_permalink 	= get_permalink($post_id);
			$post_image 		= get_the_post_thumbnail_url( $post_id, 'full' );
			$post_title			= $fn_post->post_title;
			$post_taxonomy		= Frel_Helper::post_taxanomy('arlo-project');
			
			$post_cats			= Frel_Helper::post_term_list($post_id, $post_taxonomy[0], false, 9999, ', ');
			$post_cats2			= Frel_Helper::post_term_list_second($post_id, $post_taxonomy[0]);
			
			$img_holder			= '<div class="img_holder"><img src="'.$post_image.'" alt="" /></div>';
			$title_holder		= '<div class="title_holder"><p>'.$post_cats.'</p><h3><a href="'.$post_permalink.'">'.$post_title.'</a></h3></div>';
			
			$fn_list 			.= '<li class="'.$post_cats2.'"><div class="item">'.$img_holder.$title_holder.'</div></li>';
			
			// categories list
			$post_cats3 		.= $post_cats2.' ';
			
			wp_reset_postdata();
		}
		$fn_list 	.= '</ul></div>';
		
		$removedLastCharacter 	= rtrim($post_cats3,", "); 				// remove last character from string
		$stringToArray 			= explode(" ", $removedLastCharacter);	// string to array
		$removeUniqueElements 	= array_unique($stringToArray);			// remove unique elements from array
		
		foreach($removeUniqueElements as $cat){
			$fn_filter 	.= '<div><a href="#" data-filter=".'.$cat.'">'.$cat.'</a></div>';
		}
		$fn_filter 	.= '</div>';
		
		// top section
		$html .= '<div class="filter_wrapper">';
		if($category_filter == 'enable'){
			$html .= $fn_filter;
		}
		$html .= $show_all;
		$html .= '</div>';
		
		
		// bottom section
		$html .= $fn_list;
		
		
		$html .= '</div></div>';
		$html .= Frel_Helper::frel_close_wrap();
		
		
		echo $html;
	}

}
